import { createWebHashHistory, createRouter } from 'vue-router'

import Layout from '@/layout/index.vue'

// 主页路由
import HomeIndex from '@/views/home/index.vue'
import HomeView from '@/views/home/home.vue'
import TodoView from '@/views/home/todo.vue'
import StartView from '@/views/home/start.vue'

// 登录页
import LoginView from '@/views/login/index.vue'

// 资产业务
import AssetsIndex from '@/views/assets/index.vue'
import AssetsTodoDetailView from '@/views/assets/todoDetail.vue'

// 个贷业务
import PersonalIndex from '@/views/personal/index.vue'
import PersonalTodoDetailView from '@/views/personal/todoDetail.vue'

// 个贷业务
import MajorIndex from '@/views/major/index.vue'
import MajorTodoDetailView from '@/views/major/todoDetail.vue'

const routes = [
  // 重定向到首页的路由
  {
    path:'/',
    redirect:'/index/home/index'
  },
  {
    path:'/index',
    redirect:'/index/home/index'
  },
  {
    path:'/index/home',
    redirect:'/index/home/index'
  },
  // 路由页面配置
  {
    path: '/index',
    component: Layout,
    name: 'index',
    children: [
      {
        // 首页配置
        path: 'home',
        component: HomeIndex,
        name: 'homeIndex',
        children: [
          {
            path: 'index',
            component: HomeView,
            name: 'homeView',
            meta: {
              title: '首页'
            },
          },
          {
            path: 'todo',
            component: TodoView,
            name: 'todoView',
            meta: {
              title: '待办'
            },
          },
          {
            path: 'start',
            component: StartView,
            name: 'startView',
            meta: {
              title: '快速发起'
            },
          },
        ]
      },
      // 登录页
      {
        path: 'login',
        component: LoginView,
        name: 'loginIndex',
      },
      // 资产业务
      {
        path: 'assets',
        component: AssetsIndex,
        name: 'assetsView',
        children: [
          {
            path: 'todoDetail',
            component: AssetsTodoDetailView,
            name: 'assetsTodoDetailView',
            meta: {
              title: '待办处理-资产'
            },
          },
        ]
      },
      // 个贷业务
      {
        path: 'personal',
        component: PersonalIndex,
        name: 'personalView',
        children: [
          {
            path: 'todoDetail',
            component: PersonalTodoDetailView,
            name: 'personalTodoDetailView',
            meta: {
              title: '待办处理-个贷'
            },
          },
        ]
      },
      // 大中型业务
      {
        path: 'major',
        component: MajorIndex,
        name: 'majorView',
        children: [
          {
            path: 'todoDetail',
            component: MajorTodoDetailView,
            name: 'majorTodoDetailView',
            meta: {
              title: '待办处理-大中型'
            },
          },
        ]
      }
    ]
  },
]

const router = createRouter({
  history: createWebHashHistory(),
  routes,
})

export default router